__title__ = 'django-uuslug'
__author__ = 'Val Neekman'
__author_email__ = 'info@neekware.com'
__description__ = "A Django slugify application that also handles Unicode"
__url__ = 'https://github.com/un33k/django-uuslug'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022 Val Neekman @ Neekware Inc.'
__version__ = '2.0.0'
